==> haskell-filelock-0.1.1.8-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.8
visibility:           public
id:                   filelock-0.1.1.8-8UTawiSgrCSD3mIi7RINE
key:                  filelock-0.1.1.8-8UTawiSgrCSD3mIi7RINE
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  0f27927ca727588ca3c85e223994fa74
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.8-8UTawiSgrCSD3mIi7RINE
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filelock-0.1.1.8-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filelock
version:              0.1.1.8
visibility:           public
id:                   filelock-0.1.1.8-EsFpjYpwjr46dPqYmtIYiE
key:                  filelock-0.1.1.8-EsFpjYpwjr46dPqYmtIYiE
license:              LicenseRef-PublicDomain
maintainer:           Andreas Abel
author:               Takano Akio
homepage:             http://github.com/haskell-pkg-janitors/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  31dece2754f9ab87ae646b1f3ef918e0
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filelock-0.1.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filelock
hs-libraries:         HSfilelock-0.1.1.8-EsFpjYpwjr46dPqYmtIYiE
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
